/* ISC license. */

#include <skalibs/skaclient.h>

skaclient const skaclient_zero = SKACLIENT_ZERO ;
